@@ -174,7 +174,7 @@
             arglist2$col <- ifelse(is_spatial_lines(obj),"black","transparent")
          if (.lgrep("point",geoType)) {
             if (!.isPackageInUse())
-               message("check 'https://github.com/exaexa/scattermore' for improve")
+               message("'ursa'-dev: check 'https://github.com/exaexa/scattermore' for points plot")
             if (!.lgrep("pch",names(arglist2))) {
                arglist2$pch <- 21
             }
